import json
import requests
import tkinter
from tkinter import filedialog


class XesWork:
    def __init__(self, work_id):
        self.url = 'https://code.xueersi.com/api/compilers/v2/{}?id={}'.format(work_id, work_id)
        self.headers = {'Content-Encoding': 'gzip',
                        'Content-Type': 'application/json',
                        'Accept': 'application/json, text/plain, */*',
                        'Accept-encoding': 'gzip, deflate, br',
                        'Cookie': '__guid=83032836.2463553885053085000.1588600148802.7158; hideShadeAdv=true; xesId=167d6ef5e04074cfab39d4ba07fba97d; is_login=1; stu_id=23350237; stu_name=23350237; userGrade=8; xes-code-id=d8bbb2b0b1824a169645f5660f1e9ae7.0258883033257fd3b25cfd6d76573efd; xes_acc=eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJ1aWQiOiIyMzM1NDcxOCIsInVzZXJfaWQiOiIyMzM1MDIzNyIsInJvbGUiOjEsImV4cCI6MTYwMDYwODkxOSwidmVyIjoiMS4wIn0.nWLlBnj_RELHH8w2lW-FA4PdB-J29zTIjAvPs2hZ05hsbU6zJAHMOen5HJCYe2DAXIrDE0He6Ga7q71AAblFUstcM-0WN4cP9qfR7H9dx2VaiIGmv3r58A1MFGt6dUVl1rNlEelQEhsglPhJl9A4uJuYfXJZVT-r9Opc4ik18kTbuVompBDQFf9Q11zJhhEkEGnigZ8tUhSRJabXQVd5V7JiMLJ4obOwiC-_ye4vRKJB30wEq1Y0OQQGaI40nDT8TDvgW_7d-cS7Ur5UR9XQkrfpZmnK9ogoPZ8Fu90KC7jE55OyKJ4WmC4VsQtMJjbjZIexvEdZ7URMCDY9ueRzbw; Hm_lvt_a8a78faf5b3e92f32fe42a94751a74f1=1601704217,1601814999,1601901328,1602060578; user-select=python; Hm_lpvt_a8a78faf5b3e92f32fe42a94751a74f1=1602073071; prelogid=52d989ba84178ca598460d979c5c2f4b; tal_token=tal173Zz7o1Qekcu2mK2sBrlvVKD7o-pRfW8N5TncB1LhdpQJ68JDnLF5JywtRwX8bXNZcSVoN7h-HQg0gsnSE1k5vFtsTEINeifp3jKtXnA2n1PdLqL7JOJsIR0wvy9fXkg-ufBjDEsE80-6OvF1H5E8OmayLYdL8DaFcihRfKPN0gKQleJIup_rZr6VGgPSGMJALtAYDr7enr8v0rilO2rLO-DODpf-xiYQLq1_4dnlKyiBHNqF3s3mA8CuTml4arSrPf1qRhgAE1Na86bXnRX5OUOmiFi_hl8U8qS6Cjg7d8k4I6; xes_run_token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiIuY29kZS54dWVlcnNpLmNvbSIsImF1ZCI6Ii5jb2RlLnh1ZWVyc2kuY29tIiwiaWF0IjoxNjAyMDczMDcwLCJuYmYiOjE2MDIwNzMwNzAsImV4cCI6MTYwMjA4NzQ3MCwidXNlcl9pZCI6IjIzMzUwMjM3IiwidWEiOiJNb3ppbGxhXC81LjAgKFdpbmRvd3MgTlQgMTAuMDsgV09XNjQpIEFwcGxlV2ViS2l0XC81MzcuMzYgKEtIVE1MLCBsaWtlIEdlY2tvKSBDaHJvbWVcLzc4LjAuMzkwNC4xMDggU2FmYXJpXC81MzcuMzYiLCJpcCI6IjIyMS4yMTkuMTEzLjEyOCJ9.92zLaZgaJ6qa0np9Ys-YikoQSCV7K71oc-cLhF1mBAc; X-Request-Id=969fcc90b8086d9f6705542bb9b9b1d8',
                        'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36'}
        self.a = requests.get(self.url, headers=self.headers)
        self.a.encoding = 'gzip'
        self.p = self.a.text
        # self.respon = self.p.encode('ascii').decode('unicode_escape')
        self.response = json.loads(self.p, strict=False)
        # self.response = self.respons.replace('{', ',').replace('}', ',').replace('\"', '').split(',')
        # del self.response[0]
        self.picture_url = self.response['data']['thumbnail']

    def get_name(self):
        return self.response['data']['name']

    def get_description(self):
        if self.response['data']['description'] == '':
            return None
        else:
            return self.response['data']['description']

    def get_likes(self):
        return self.response['data']['likes']

    def get_unlikes(self):
        return self.response['data']['unlikes']

    def get_favorites(self):
        return self.response['data']['favorites']

    def get_adapt_numbers(self):
        return self.response['data']['source_code_views']

    def download_icon(self):
        import os
        os.makedirs('./', exist_ok=True)
        from urllib.request import urlretrieve
        urlretrieve(self.picture_url, './icon.jpg')
        os.system('icon.jpg')
        string = "start explorer " + os.getcwd()
        os.system(string)
        return True

    def get_author_name(self):
        return self.response['data']['username']

    def get_author_id(self):
        return self.response['data']['user_id']

    def get_work_tags(self):
        tags = self.response['data']['tags']
        list_of_tags = tags.split()
        return list_of_tags

    def get_hot(self):
        return self.response['data']['popular_score']

    def get_views(self):
        return self.response['data']['views']

    def get_first_published_time(self):
        return self.response['data']['published_at']

    def get_latest_modified_time(self):
        return self.response['data']['modified_at']

    def get_latest_updated_time(self):
        return self.response['data']['updated_at']

    def get_created_time(self):
        return self.response['data']['created_at']

    def is_hidden_code(self):
        if self.response['data']['hidden_code'] == 2:
            return False
        else:
            return True


class XesUserSpace:
    def __init__(self, user_id):
        self.url_1 = 'https://code.xueersi.com/api/space/index?user_id=' + str(user_id)
        self.url_2 = 'https://code.xueersi.com/api/space/profile?user_id=' + str(user_id)
        self.headers = {
                    'Content-Type': 'application/json',
                    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) "
                                  "Chrome/78.0.3904.108 Safari/537.36"}
        self.p_1 = requests.get(self.url_1, headers=self.headers).text
        self.p_2 = requests.get(self.url_2, headers=self.headers).text
        self.response_index = json.loads(self.p_1, strict=False)
        self.response_profile = json.loads(self.p_2, strict=False)
        self.head_url = self.response_profile['data']['avatar_path']

    def download_user_head(self):
        # 类似于分类讨论【捂脸】
        import tkinter
        from tkinter import filedialog
        h = self.head_url[-3] + self.head_url[-2] + self.head_url[-1]
        if h == 'gif':
            root = tkinter.Tk()
            root.geometry("400x300")
            root.title("请勿关掉此窗口")
            ask = tkinter.filedialog.askdirectory(title='请选择图片的保存文件夹') + '\\' + "icon.gif"
            root.withdraw()
            res = requests.get(url=self.head_url).content
            root.destroy()
            with open(ask, "wb") as f:
                f.write(res)
            return "头像下载完成！"
        elif h == 'jpg':
            root = tkinter.Tk()
            root.geometry("400x300")
            root.title("请勿关掉此窗口")
            ask = tkinter.filedialog.askdirectory(title='请选择图片的保存文件夹') + '\\' + "icon.jpg"
            root.withdraw()
            res = requests.get(url=self.head_url).content
            root.destroy()
            with open(ask, "wb") as f:
                f.write(res)
            return "头像下载完成！"
        else:
            root = tkinter.Tk()
            root.geometry("400x300")
            root.title("请勿关掉此窗口")
            ask = tkinter.filedialog.askdirectory(title='请选择图片的保存文件夹') + '\\' + "icon.png"
            root.withdraw()
            res = requests.get(url=self.head_url).content
            root.destroy()
            with open(ask, "wb") as f:
                f.write(res)
            return "头像下载完成！"

    def get_fans_number(self):
        # 这孩子多少粉了？
        return self.response_profile['data']['fans']

    def get_follows_number(self):
        # 这孩子有几个偶像（关注了几个人）？
        return self.response_profile['data']['follows']

    def is_follow(self):
        # 你有没有关注他呢？？？
        if self.response_profile['data']['is_follow'] == 1:
            return True
        else:
            return False

    def get_realname(self):
        # 他真名叫啥？
        return self.response_profile['data']['realname']

    def get_sign(self):
        # 个性签名是什么？
        return self.response_profile['data']['signature']

    def get_number_of_works(self):
        # 他一共有多少作品（加上没发布的）？
        return self.response_index['data']['overview']['works']

    def get_number_of_likes(self):
        # 他的所有作品一共获了多少赞？
        return self.response_index['data']['overview']['likes']

    def get_number_of_views(self):
        # 总浏览量
        return self.response_index['data']['overview']['views']

    def get_adapted_number(self):
        # 被改编多少次？
        return self.response_index['data']['overview']['source_code_views']

    def get_favorites(self):
        # 被收藏多少次？
        return self.response_index['data']['overview']['favorites']

    def get_first_eight_fans(self):
        # 获取他前八个粉丝的姓名和id
        a_list = []
        for i in self.response_index['data']['fans']['data']:
            a_list.append((i['id'], i['realname']))
        return a_list

    def get_first_eight_favourites(self):
        # 获取他前八个收藏的id、name、作者id和作者名
        a_list = []
        for i in self.response_index['data']['favourites']['data']:
            a_list.append((i['id'], i['name'], i['user_id'], i['user_name']))
        return a_list

    def get_representative_work(self):
        # 代表作
        return self.response_index['data']['representative_work']['name']




import tkinter as tk
import webbrowser
import re

window = tk.Tk()
window.title('查询器')
window.geometry('500x300')

a = tk.Label(window, text='请在下面输入你要破译的作品网址')
a.pack()

b1 = tk.StringVar()
b = tk.Entry(window, textvariable=b1)
b.pack()


def checking():
    b2 = b1.get()
    d = re.findall(r"\d+", b2)
    d = ''.join(d)
    s = "http://code.xueersi.com/code/ide/code/" + d
    webbrowser.open(s)


c = tk.Button(window, text='破译', command=checking)
c.pack()


window.mainloop()



from tkinter import *
from tkinter import messagebox

import requests

root = Tk()
root.title('翻译(只支持中译英)')
root.geometry('370x100')
s_with = root.winfo_screenwidth()
s_height = root.winfo_screenheight()
l_x = str(round((s_with - 370) / 2))
l_y = str(round((s_height - 100) / 2))
root.geometry('+' + l_x + '+' + l_y)
lable = Label(root, text='请输入内容：')
lable.grid()
extry = Entry(root, font=('微软雅黑', 15))
extry.grid(row=0, column=1)
res = StringVar()
lable1 = Label(root, text='翻译结果：')
lable1.grid(row=1, column=0)
extry1 = Entry(root, font=('微软雅黑', 15), textvariable=res)
extry1.grid(row=1, column=1)


def translate():
    content = extry.get()
    content = content.strip()
    if content == '':
        messagebox.showinfo('提示', '请输入翻译内容')
    else:
        url = "http://fanyi.youdao.com/translate?smartresult=dict&smartresult=rule"
        data = {}
        data['i'] = content
        data['from'] = 'AUTO'
        data['to'] = 'AUTO'
        data['smartresult'] = 'dict'
        data['client'] = 'fanyideskweb'
        data['salt'] = '1538295833420'
        data['sign'] = '07'
        data['doctype'] = 'json'
        data['version'] = '2.1'
        data['keyfrom'] = 'fanyi.web'
        data['action'] = 'FY_BY_REALTIME'
        data['typoResult'] = 'false'
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/67.0.3396.99 Safari/537.36'
        }
        result = requests.post(url, data, headers=headers)
        trans = result.json()
        tran = trans['translateResult'][0][0]['tgt']
        res.set(tran)


button = Button(root, text='点击翻译', width='10', command=translate)
button.grid(row=2, column=0, sticky=W)
exit_button = Button(root, text='退出键', width='10', command=root.quit)
exit_button.grid(row=2, column=1, sticky=E)
root.mainloop()



class HuoYanLibRequestsError(Exception):
    """Nothing"""


def _raise_huoyanlibrequestserror_sys():
    raise HuoYanLibRequestsError(
        'length of object \'sys.argv\' is not enough, please use 360 explorer -- xueersi running this function'
    )


def _raise_huoyanlibrequestserror_socket():
    raise HuoYanLibRequestsError('can\'t connect to socket server.')



from huoyanlib import _raise_huoyanerror_object


colors = [31, 32, 33, 34, 35, 36, 37, 91, 92, 93, 94, 95, 96, 97]


def spark(word, time_of_spark):
    import random
    import time
    import sys
    try:
        times = int(time_of_spark / 0.1)
    except ValueError:
        _raise_huoyanerror_object()
    try:
        for i in range(times):
            print("\033[{}m{}".format(random.choice(colors), word))
            time.sleep(0.1)
            sys.stdout.write('\033[2J\033[00H')
    except UnboundLocalError:
        _raise_huoyanerror_object()



from tkinter import *


class Calculator(Frame):
    def __init__(self):
        Frame.__init__(self)
        self.pack(expand=YES, fill=BOTH)
        self.master.title('计算器')
        self.master.rowconfigure(0, weight=1)
        self.master.columnconfigure(0, weight=1)
        self.grid(sticky=W + E + N + S)
        display = StringVar()
        entry = Entry(self, relief=SUNKEN, textvariable=display)
        entry.grid(row=0, column=0, columnspan=4, sticky=W + E + N + S)
        grid = '789+456-123*0./='
        for index, textChar in enumerate(grid):
            a = Button(self, text=textChar, width=5, command=lambda text=textChar: display.set(display.get() + text))
            a.grid(row=1 + index // 4, column=index % 4)
            button_text = a.cget("text")
            if button_text == '=':
                a.config(command=lambda: display.set(eval(display.get())))
            b = Button(self, text="clear", width=20, command=lambda: display.set(""))
            b.grid(row=7, column=0, columnspan=4, sticky=W + E + N + S)


if __name__ == '__main__':
    Calculator().mainloop()



from time import *
from huoyanlib import _raise_huoyanerror_object


def clean(t):
    import sys
    try:
        t = int(t)
        sleep(t)
    except ValueError:
        _raise_huoyanerror_object()
    sys.stdout.write('\033[2J\033[00H')


def clear():
    import sys
    sys.stdout.write('\033[2J\033[00H')



import requests
import bs4
import webbrowser
import tkinter as tk
from tkinter import ttk
from tkinter import messagebox


def get_news():
    def search():
        kw = e1.get()
        if len(kw.replace(" ", "")) == 0:
            messagebox.showwarning("火焰新闻 - 警告", "搜索内容不能为空！", parent=win)
            return
        x = searchList.get_children()
        for item in x:
            searchList.delete(item)
        response = requests.get("https://36kr.com/search/articles/" + kw).text
        soup = bs4.BeautifulSoup(response, "lxml")
        data1 = soup.find_all(name="a", class_="article-item-title weight-bold")
        data2 = soup.find_all(name="a", class_="article-item-description ellipsis-2")
        for x in range(len(data1)):
            name = data1[x].text
            abstract = data2[x].text
            link = "https://36kr.com" + data1[x]["href"]

            searchList.insert("", x, values=(name, abstract, link))

    win = tk.Tk()
    win.title("火焰新闻")
    win.geometry("800x500")
    win.resizable(False, False)

    l1 = tk.Label(win, text="火焰新闻", font=(None, 40), fg="red")
    l1.pack()

    tk.Label(win).pack()

    frame1 = tk.Frame(win)

    e1 = ttk.Entry(frame1)
    e1.grid(row=0, column=0)
    e1.bind("<Return>", search)

    b1 = ttk.Button(frame1, text="搜索", command=search)
    b1.grid(row=0, column=1)

    frame1.pack()

    l4 = tk.Label(win, text="(以下内容来自36kr.com)")
    l4.pack()

    frame2 = tk.Frame(win)

    columns = ("标题", "摘要", "链接")
    columnWidths = (100, 250, 150)

    searchList = ttk.Treeview(frame2, show="headings", columns=columns, selectmode="browse")
    searchList.grid(row=0, column=0, ipadx=60, ipady=15)

    sb1 = tk.Scrollbar(frame2)
    sb1.grid(row=0, column=1, ipady=100)

    sb2 = tk.Scrollbar(frame2, orient="horizontal")
    sb2.grid(row=1, column=0, ipadx=260)

    searchList.config(yscrollcommand=sb1.set)
    searchList.config(xscrollcommand=sb2.set)
    sb1.config(command=searchList.yview)
    sb2.config(command=searchList.xview)

    for x in range(len(columns)):
        searchList.column(columns[x], anchor="center", width=columnWidths[x])
        searchList.heading(columns[x], text=columns[x])

    frame2.pack()

    frame3 = tk.Frame(win)

    def copytext(item):
        selection = searchList.item(searchList.focus())["values"]
        if selection == "":
            messagebox.showwarning("火焰新闻 - 警告", "请选中要复制的那行！", parent=win)
            return
        win.clipboard_append(selection[item])

    b2 = ttk.Button(frame3, text="复制标题", command=lambda: copytext(0))
    b2.grid(row=0, column=0)

    b3 = ttk.Button(frame3, text="复制摘要", command=lambda: copytext(1))
    b3.grid(row=0, column=1)

    b4 = ttk.Button(frame3, text="复制链接", command=lambda: copytext(2))
    b4.grid(row=0, column=2)

    def openurl():
        selection = searchList.item(searchList.focus())["values"]
        if selection == "":
            messagebox.showwarning("火焰新闻 - 警告", "请选中要打开链接的那行！", parent=win)
            return
        webbrowser.open(selection[2])

    b5 = ttk.Button(frame3, text="打开链接", command=openurl)
    b5.grid(row=0, column=3)

    frame3.pack()

    win.mainloop()


get_news()



import matplotlib.pyplot as plt


class MatPlot:
    def __init__(self):
        pass

    def draw_plot(self, x, y, linewidth, title, xlabel, ylabel):
        plt.plot(x, y, linewdith=linewidth)
        plt.title(title, fontsize=24)
        plt.xlabel(xlabel, fontsize=14)
        plt.ylabel(ylabel, fontsize=14)
        plt.tick_params(axis='both', labelsize=14)
        plt.show()

    def draw_scatter(self, x, y):
        plt.scatter(x, y, s=40)

    def show_img(self, img_name):
        from matplotlib.image import imread
        img = imread(img_name)
        plt.imshow(img)
        plt.show()



from time import *
import sys


def cz_print(text, cz):
    sys.stdout.write("\r " + "" * 60 + "\r")
    sys.stdout.flush()
    for c in text:
        sys.stdout.write(c)
        sys.stdout.flush()
        sleep(cz)


class HuoYanError(Exception):
    """nothing"""


def _raise_huoyanerror_object():
    raise HuoYanError('Please use the right object')


def _raise_huoyanerror_parameter():
    raise HuoYanError('All parameters you pass in must have default values')


__version__ = '2.2.0'
__author__ = 'F.S'
__all__ = ["request", 'c', 'log_in', 'print', 'print_logo', 'python_plot',
           'spark_word']



import setuptools


setuptools.setup(
    name='huoyanlib',
    version='2.2.0',
    author='RuiQin Li',
    author_email="2647154420@qq.com",
    description='学而思火焰工作室专属库',
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)




colors = [31, 32, 33, 34, 35, 36, 37, 91, 92, 93, 94, 95, 96, 97]


def spark(word, times):
    import random
    import time
    import sys
    for i in range(times):
        print("\033[{}m{}".format(random.choice(colors), word))
        time.sleep(0.1)
        sys.stdout.write('\033[2J\033[00H')


def spark_2(word, times):
    from random import choice
    import time
    import sys
    word_2 = []
    for i in range(0, len(word)):
        word_2.append(word[i])
    word_3 = []
    for i in range(times):
        for iii in word_2:
            word_3.append('\033[{}m{}'.format(choice(colors), iii))
        for ii in word_3:
            print(ii, end='')
            time.sleep(0.1)
            sys.stdout.write('\033[2J\033[00H')
        print("\n")


spark_2('hello', 25)



def help(name):
    """
    大家有没有觉得系统自带的help函数输出的东西你都看不懂呢？
    那就来试试这个函数吧！我把所有讲解都换成了中文！
    """
    unused = [
        'callable',
        'chr',
        'compile',
        'copyright',
        'credits',
        'dir',

    ]

    if name == 'abs':
        print("常用形参数：1（int类型）\n翻译：就是返回绝对值")
    elif name == 'all':
        print("常用形参数：1（可迭代对象，也就是说可以是元组或列表）\n翻译：如果bool(x)对迭代中的所有值x都为真，则返回True。")
        print("（如果列表是空的，会返回True）")
    elif name == 'any':
        print("常用形参数：1（可迭代对象，也就是说可以是元组或列表）\n翻译：如果bool(x)对迭代中的任何x都为真，则返回True。")
        print("（如果列表是空的，会返回False）")
    elif name == 'ascii':
        print("常用形参数：1（任何类型）\n翻译：返回对象的纯ascii表示形式。")
        print("它的前身是Python2里面的repr()")
    elif name == 'bin':
        print("常用形参数：1（int类型）\n翻译：返回整数的二进制表达形式")
    elif name == 'breakpoint':
        print("常用形参数：1（任何类型）\n翻译：这个函数调用了sys.breakpointthook()")
        print("Breakpointhook()必须接受传递的任何参数。默认情况下，这会将您放入pdb调试器。")
    elif name == 'credits':
        print("没有形参，没有用处，就是一个声明，调用后会输出以下内容：")
        print("Thanks to CWI, CNRI, BeOpen.com, Zope Corporation and a cast of thousands")
        print("for supporting Python development.  See www.python.org for more information.")
    elif name == 'delattr':
        print("形参数：2（一个是列表名，第二个是元素名\n翻译：从给定对象中删除命名属性。 Delattr (x，‘ y’)等价于“ del x.y”")
    elif name == 'divmod':
        print('形参数：2（都是int类型）\n翻译：divmod(x, y)返回一个元组，两个元素分别是x÷y的商（整数）和余数')
    elif name == 'eval':
        print('这个函数被大家吹的神乎其神，其实并不厉害，只是把传给他的参数尝试转换为Python代码')
    elif name == 'exec':
        print('跟eval函数类似，没什么好解释的')
    elif name == 'exit':
        print('不接受参数，作用就是直接停止程序')
    elif name == 'format':
        print('接收形参数：无数，主要作用就是编辑字符串')
    elif name == 'getatter':
        print('获取属性值')
    elif name == 'globals':
        print("返回全局变量的字典")
    elif name == 'hasattr':
        print("hasattr(x, y)检查对象x有没有对象y，如果对象有该属性返回True，否则返回False")
    elif name == 'hash':
        print("返回对象的哈希值（别问我哈希值是什么，他解释太长了，自己查去）")
    elif name == 'help':
        print("这个原版的help函数返回一个函数的功能（英文的），所以建议你们使用我这个库【滑稽】")
    elif name == 'hex':
        print("返回整数的16进制表达形式")



import requests
import bs4
import urllib
import sys
import re
from huoyanlib.request import _raise_huoyanlibrequestserror_sys, _raise_huoyanlibrequestserror_socket
from socket import *


def get_user_cookies():
    try:
        new = sys.argv[1]
        new = new.replace(';', ' ')
        new = new.split()
        result = new[4]
        result = result.replace('stu_id=', ' ')
        result = result.strip()
        return int(result)
    except IndexError:
        _raise_huoyanlibrequestserror_sys()


def login(user, password):
    try:
        s = socket(AF_INET, SOCK_STREAM)
        s.connect(("pan.asunc.cn", 22001))
        s.send(user.encode("utf-8"))
        s.send(password.encode("utf-8"))
        print(s.recv(1).decode("utf-8"))
    except:
        _raise_huoyanlibrequestserror_socket()



from tkinter import *
import random
import string
from datetime import datetime

root = Tk()
root.title("练习打字,测试老师的速度!")
Label(root, text='题目:').grid(row=0)
Label(root, text='试卷:').grid(row=1)
Label(root, text='考试结果:').grid(row=2)
v1 = StringVar()
v2 = StringVar()
v3 = StringVar()
v1.set("点击'开始测试'按钮开始出题,想复制?不可能的(调皮)")
e1 = Entry(root, text=v1, state='disabled', width=40, font=('宋体', 14))
e2 = Entry(root, textvariable=v2, width=40, font=('宋体', 14))
e3 = Label(root, textvariable=v3, width=40, font=('宋体', 10), foreground='red')
e1.grid(row=0, column=1, padx=10, pady=20)
e2.grid(row=1, column=1, padx=10, pady=20)
e3.grid(row=2, column=1, padx=10, pady=20)
text = Text(root, width=80, height=7)
text.grid(row=4, column=0, columnspan=2, pady=5)


class TypingTest:
    def __init__(self):
        self.time_list = []
        self.letterNum = 20
        self.letterStr = ''.join(random.sample(string.printable.split(' ')[0], self.letterNum))
        self.examination_paper = ''

    def time_calc(self):
        self.time_list.append(datetime.now())
        yield

    def create_exam(self):
        text.delete(0.0, END)
        v1.set(self.letterStr)
        self.time_calc().__next__()
        text.insert(END, "开始：%s \n" % str(self.time_list[-1]))
        user_only1.config(state='active')

    def score(self):
        wrong_index = []
        self.time_calc().__next__()
        text.insert(END, "结束:%s\n" % str(self.time_list[-1]))
        use_time = (self.time_list[-1] - self.time_list[-2]).seconds
        self.examination_paper = v2.get()
        if len(self.examination_paper) > self.letterNum:
            v3.set("输入数据有错误，作答数大于考题数")
        else:
            right_num = 0
            for z in range(len(self.examination_paper)):
                if self.examination_paper[z] == self.letterStr[z]:
                    right_num += 1
                else:
                    wrong_index.append(z)
            if right_num == self.letterNum:
                v3.set("完全正确,正确率%.2f%%用时：%s秒" % ((right_num * 1.0) / self.letterNum * 100, use_time))
            else:
                v3.set("正确率%.2f%%用时：%s 秒" % ((right_num * 1.0) / self.letterNum * 100, use_time))
                text.insert(END, "题目：%s\n" % self.letterStr)
                tag_info = list(map(lambda x: '4.' + str(x + 3), wrong_index))
                text.insert(END, "作答：%s\n" % self.examination_paper)
                for i in range(len(tag_info)):
                    text.tag_add("tag1", tag_info[i])
                    text.tag_config("tag1", background='red')
                    user_only1.config(state='disabled')


TypingTest = TypingTest()
Button(root, text="开始测试", width=10, command=TypingTest.create_exam).grid(row=3, column=0, sticky=W, padx=30, pady=5)
user_only1 = Button(root, text="交卷", width=10, command=TypingTest.score, state='disable')
user_only1.grid(row=3, column=1, sticky=E, padx=30, pady=5)
mainloop()



import sys
import time


def h_print(text, time_=0.3):
    if time_ is not None:
        sys.stdout.write("\r " + " " * 60 + "\r")
        sys.stdout.flush()
        for c in text:
            sys.stdout.write(c)
            sys.stdout.flush()
            time.sleep(time_)

